@@ -15,16 +15,12 @@ class Environment(object):
 
     @classmethod
     def from_document_settings(cls, settings):
-        try:
-            return settings._changelog_env
-        except AttributeError:
-            for cls in cls.env_classes:
-                e = cls.from_document_settings(settings)
-                if e is not None:
-                    settings._changelog_env = e
-                    return e
+        for cls in cls.env_classes:
+            e = cls.from_document_settings(settings)
+            if e is not None:
+                return e
 
-            raise NotImplementedError("TODO")
+        raise NotImplementedError("TODO")
 
     @property
     def temp_data(self):
